# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-05-22 15:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0002_auto_20200330_1531'),
    ]

    operations = [
        migrations.AddField(
            model_name='dashboard',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='dashboard',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
    ]
